#[repr(C)]pub struct Vertex2D {
pub x: f32,
pub y: f32,
}Expand description
Vertex for GPU rendering (2D position only).
This is the minimal vertex format for text rendering. Position is in normalized device coordinates or pixel space depending on your pipeline.
Compatible with wgpu VertexFormat::Float32x2 at offset 0.
Memory Layout
- Size: 8 bytes
- Alignment: 4 bytes
- Can be cast to
&[u8]viabytemuck::cast_slice()oras_bytes()
Example (wgpu)
ⓘ
wgpu::VertexBufferLayout {
array_stride: 8,
step_mode: wgpu::VertexStepMode::Vertex,
attributes: &[wgpu::VertexAttribute {
offset: 0,
shader_location: 0,
format: wgpu::VertexFormat::Float32x2,
}],
}Fields
x: f32X coordinate
y: f32Y coordinate
Implementations